/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "AbstractLogView.h"
#include "Log.h"

namespace wxGUI
{

AbstractLogView::AbstractLogView(Log& log, bool visible)
:	m_visibilityReporter(log.getViewVisibilityReporter()),
	m_isVisible(visible)
{
	if (m_isVisible) {
		m_visibilityReporter(true);
	}
}

AbstractLogView::~AbstractLogView()
{
	if (m_isVisible) {
		m_visibilityReporter(false);
	}
}

void
AbstractLogView::reportVisibility(bool visible)
{
	if (visible != m_isVisible) {
		m_isVisible = visible;
		m_visibilityReporter(visible);
	}
}

} // namespace wxGUI
